import React, { useState, useEffect, useRef, useCallback } from "react";
import axios from "axios";
import {
  Dialog,
  DialogContent,
  DialogTitle,
  Button,
  TextField,
  DialogActions,
} from "@mui/material";
import { isAutheticated } from "../../auth";
import swal from "sweetalert";
import debounce from "lodash.debounce";

const SCmodal = ({ openSCModal, handleCloseSCModal, refreshData, rdid }) => {
  const token = isAutheticated();
  const [modalSalesCoordinators, setmodalSalesCoordinators] = useState(
    []
  );
  const [modalTotalData, setModalTotalData] = useState(0);
  const [modalcurrentPage, setmodalCurrentPage] = useState(1);
  const [modalitemPerPage, setmodalItemPerPage] = useState(10);
  const [loading, setLoading] = useState(false);
  const scnameRef = useRef();
  const scmobileRef = useRef();

  const getSalesCoOrdinatorsData = async () => {
    setLoading(true);
    try {
      const res = await axios.get(`/api/salescoordinator/getAll`, {
        headers: {
          Authorization: `Bearer ${token}`,
        },
        params: {
          page: modalcurrentPage,
          show: modalitemPerPage,
          name: scnameRef.current?.value,
          mobileNumber: scmobileRef.current?.value,
        },
      });
      setmodalSalesCoordinators(res.data?.salesCoOrinators);
      setModalTotalData(res.data?.total_data);
    } catch (err) {
      const msg = err?.response?.data?.message || "Something went wrong!";
      swal({
        title: "Error",
        text: msg,
        icon: "error",
        button: "Retry",
        dangerMode: true,
      });
    } finally {
      setLoading(false);
    }
  };

  const handleSCMap = (id) => {
    const data = {
      mappedSC: id,
    };
    axios
      .put(`/api/mapped/${rdid}`, data, {
        headers: {
          Authorization: `Bearer ${token}`,
        },
      })
      .then((res) => {
        swal({
          title: "Success",
          text: "Principal Distributor mapped successfully!",
          icon: "success",
          button: "Ok",
        });
        refreshData(); // Call the refresh function
        handleCloseSCModal();
      })
      .catch((err) => {
        const msg = err?.response?.data?.message || "Something went wrong!";
        swal({
          title: "Error",
          text: msg,
          icon: "error",
          button: "Retry",
          dangerMode: true,
        });
      });
  };

  useEffect(() => {
    getSalesCoOrdinatorsData();
  }, [modalcurrentPage]);

  const handleInputChange = useCallback(
    debounce(() => {
      getSalesCoOrdinatorsData();
    }, 1000),
    []
  );
  const handleNextPage = () => {
    setmodalCurrentPage((prev) => prev + 1);
  };
  const handlePreviousPage = () => {
    setmodalCurrentPage((prev) => prev - 1);
  };
  return (
    <Dialog
      open={openSCModal}
      onClose={handleCloseSCModal}
      fullWidth
      maxWidth="lg"
    >
      <DialogTitle>Search and Add Sales Coordinator</DialogTitle>
        <DialogContent>
          <div
            style={{
              display: "flex",
              gap: "16px",
              marginBottom: "2rem",
              marginTop: "-1rem",
            }}
          >
            <TextField
              label="Sales Coordinator Name"
              placeholder="Sales Coordinator name"
              inputRef={scnameRef}
              onChange={handleInputChange}
              disabled={loading}
              style={{ flex: 1, marginRight: "16px" }}
            />
            <TextField
              style={{ flex: 1 }}
              label="Mobile Number"
              placeholder="Mobile Number"
              inputRef={scmobileRef}
              onChange={handleInputChange}
              disabled={loading}
            />
          </div>

          <div className="table-responsive table-shoot mt-3">
            <table className="table table-centered table-nowrap">
              <thead>
                <tr>
                  <th>Id</th>
                  <th>Name</th>
                  <th>Mobile</th>
                  <th>TM</th>
                  <th>Action</th>
                </tr>
              </thead>
              <tbody>
                {modalSalesCoordinators.map((coordinator) => (
                  <tr key={coordinator._id}>
                    <td>{coordinator.uniqueId}</td>
                    <td>{coordinator.name}</td>
                    <td>{coordinator.mobileNumber}</td>
                    <td>{coordinator.mappedby?.name || "N/A"}</td>
                    <td>
                      <Button
                        variant="contained"
                        color="primary"
                        onClick={() => handleSCMap(coordinator._id)}
                      >
                        Add
                      </Button>
                    </td>
                  </tr>
                ))}
              </tbody>
            </table>
          </div>
          <div className="d-flex justify-content-between">
            <div>
              Showing {modalSalesCoordinators?.length} of {modalTotalData}{" "}
              entries
            </div>
            <div>
              <button
                onClick={handlePreviousPage}
                disabled={modalcurrentPage === 1 || loading}
                className="btn btn-primary"
              >
                Previous
              </button>
              <button
               onClick={handleNextPage}
                disabled={
                  modalSalesCoordinators?.length < modalitemPerPage || loading
                }
                className="btn btn-primary ml-2"
              >
                Next
              </button>
            </div>
          </div>
        </DialogContent>
        <DialogActions>
          <Button onClick={handleCloseSCModal} color="secondary">
            Cancel
          </Button>
        </DialogActions>
    </Dialog>
  );
};

export default SCmodal;
